@@ -3,10 +3,13 @@ use Mojo::Base -base;
 
 use Scalar::Util qw(blessed);
 use Mojo::Util qw(trim);
-use CellBIS::SQL::Abstract::Utils;
+use CellBIS::SQL::Abstract::Util;
+use CellBIS::SQL::Abstract::Table;
 
 # ABSTRACT: SQL Abstract
-our $VERSION = '0.5';
+our $VERSION = '0.6';
+
+has 'QueryUtil' => sub { state $qu = CellBIS::SQL::Abstract::Util->new };
 
 # For Query Insert :
 # ------------------------------------------------------------------------
@@ -30,15 +33,14 @@ sub insert {
   if ((scalar @table_field) == (scalar @table_data)) {
     
     if ($type && $type eq 'no-pre-st') {
-      $value_col = join ', ', @table_data;
+      $value_col = join ', ', $self->QueryUtil->replace_data_value_insert_no_pre_st(\@table_data);
     }
     elsif ($type && $type eq 'pre-st') {
-      @get_data_value = CellBIS::SQL::Abstract::Utils->replace_data_value_insert(\@table_data);
+      @get_data_value = $self->QueryUtil->replace_data_value_insert(\@table_data);
       $value_col = join ', ', @get_data_value;
     }
     else {
-      @get_data_value = CellBIS::SQL::Abstract::Utils->replace_data_value_insert(\@table_data);
-      $value_col = join ', ', @get_data_value;
+      $value_col = join ', ', $self->QueryUtil->replace_data_value_insert_no_pre_st(\@table_data);
     }
     
     $field_col = trim($field_col);
@@ -57,26 +59,22 @@ sub update {
   my $self = shift;
   my $arg_len = scalar @_;
   my ($table_name, $column, $value, $clause, $type);
-  
-  if ($arg_len == 4) {
-    ($table_name, $column, $value, $clause) = @_;
-  }
-  if ($arg_len == 5) {
-    ($table_name, $column, $value, $clause, $type) = @_;
-  }
   my $data = '';
   
+  ($table_name, $column, $value, $clause) = @_ if $arg_len == 4;
+  ($table_name, $column, $value, $clause, $type) = @_ if $arg_len >= 5;
+  
   my @table_field = @{$column};
   my $field_change = '';
   my $where_clause = '';
   
   if ($type && $type eq 'no-pre-st') {
-    my @get_value = CellBIS::SQL::Abstract::Utils->col_with_val($column, $value);
+    my @get_value = $self->QueryUtil->col_with_val($column, $value);
     $field_change = join ', ', @get_value;
     
     if (exists $clause->{where}) {
-      $where_clause = CellBIS::SQL::Abstract::Utils->create_clause($clause);
-      $data = "UPDATE $table_name SET $field_change" . $where_clause;
+      $where_clause = $self->QueryUtil->create_clause($clause);
+      $data = "UPDATE $table_name \nSET $field_change \n$where_clause";
     }
     
   }
@@ -85,17 +83,17 @@ sub update {
     $field_change .= '=?';
     
     if (exists $clause->{where}) {
-      $where_clause = CellBIS::SQL::Abstract::Utils->create_clause($clause);
-      $data = "UPDATE $table_name SET $field_change" . $where_clause;
+      $where_clause = $self->QueryUtil->create_clause($clause);
+      $data = "UPDATE $table_name \nSET $field_change \n$where_clause";
     }
   }
   else {
-    $field_change = join '=?, ', @table_field;
-    $field_change .= '=?';
-    
+    my @get_value = $self->QueryUtil->col_with_val($column, $value);
+    $field_change = join ', ', @get_value;
+  
     if (exists $clause->{where}) {
-      $where_clause = CellBIS::SQL::Abstract::Utils->create_clause($clause);
-      $data = "UPDATE $table_name SET $field_change" . $where_clause;
+      $where_clause = $self->QueryUtil->create_clause($clause);
+      $data = "UPDATE $table_name \nSET $field_change \n$where_clause";
     }
   }
   return $data;
@@ -111,8 +109,8 @@ sub delete {
   if (ref($clause) eq "HASH") {
     #    my $size_clause = scalar keys %{$clause};
     if (exists $clause->{where}) {
-      my $where_clause = CellBIS::SQL::Abstract::Utils->create_clause($clause);
-      $data = "DELETE FROM $table_name" . $where_clause;
+      my $where_clause = $self->QueryUtil->create_clause($clause);
+      $data = "DELETE FROM $table_name \n$where_clause";
     }
   }
   return $data;
@@ -139,6 +137,21 @@ sub select_join {
   $data = $self->_qSelectJoin_arg3(@_) unless ($arg_len < 3);
   return $data;
 }
+
+# For Create Table :
+# ------------------------------------------------------------------------
+sub create_table {
+  my $self = shift;
+  my $arg_len = scalar @_;
+  my $result = '';
+  
+  if ($arg_len >= 3) {
+    my $tables = CellBIS::SQL::Abstract::Table->new();
+    $result = $tables->create_query_table(@_);
+  }
+  return $result;
+}
+
 # For Action Query String - "select" - arg3 :
 # ------------------------------------------------------------------------
 sub _qSelect_arg3 {
@@ -155,23 +168,19 @@ sub _qSelect_arg3 {
     my $size_clause = scalar keys %{$clause};
     
     if ($size_clause != 0) {
-      $where_clause = CellBIS::SQL::Abstract::Utils->create_clause($clause);
+      $where_clause = $self->QueryUtil->create_clause($clause);
       if (scalar @col == 0) {
-        $data = 'SELECT * FROM '.$table_name . $where_clause;
-      }
-      
-      elsif (scalar @col => 1) {
+        $data = 'SELECT * FROM '.$table_name . "\n" . $where_clause;
+      } else {
         $field_change = ref($column) eq "ARRAY" ? (join ', ', @col) : '*';
-        $data = 'SELECT '. $field_change . ' FROM '. $table_name . $where_clause;
+        $data = 'SELECT '. $field_change . " \nFROM ". $table_name . "\n" . $where_clause;
       }
       
     }
     else {
       if ($size_col == 0) {
         $data = "SELECT * FROM $table_name";
-      }
-      
-      if ($size_col >= 1) {
+      } else {
         $field_change = join ', ', @col;
         $data = "SELECT $field_change FROM $table_name";
       }
@@ -182,8 +191,7 @@ sub _qSelect_arg3 {
     
     if ($size_col == 0) {
       $data = "SELECT * FROM $table_name";
-    }
-    if ($size_col >= 1) {
+    } else {
       $field_change = join ', ', @col;
       $data = "SELECT $field_change FROM $table_name";
     }
@@ -207,12 +215,12 @@ sub _qSelectJoin_arg3 {
   
   if (ref($clause) eq "HASH") {
     if (exists $clause->{join}) {
-      $join_clause = CellBIS::SQL::Abstract::Utils->for_onjoin($clause, $table_name);
-      $where_clause = CellBIS::SQL::Abstract::Utils->create_clause($clause);
-      $data = "SELECT $field_change $join_clause" . $where_clause;
+      $join_clause = $self->QueryUtil->for_onjoin($clause, $table_name);
+      $where_clause = $self->QueryUtil->create_clause($clause);
+      $data = "SELECT $field_change $join_clause" . "\n" . $where_clause;
     }
     else {
-      $where_clause = CellBIS::SQL::Abstract::Utils->create_clause($clause);
+      $where_clause = $self->QueryUtil->create_clause($clause);
       $data = "SELECT $field_change FROM $table_name";
     }
   }
@@ -222,25 +230,13 @@ sub _qSelectJoin_arg3 {
   return $data;
 }
 
+sub to_one_liner {
+  my ($self, $result) = @_;
+  
+  $result =~ s/\t+//g;
+  $result =~ s/\,\s+/\, /g;
+  $result =~ s/\s+/ /g;
+  return $result;
+}
+
 1;
-
-=encoding utf8
-
-=head1 NAME
-
-CellBIS::SQL::Abstract - SQL Abstract
-
-=head1 DESCRIPTION
-
-The purpose of this module is to support SQL abstraction in L<Mojo::mysql>.
-This module inherits from L<Mojo::Base>
-
-=head1 AUTHOR
-
-Achmad Yusri Afandi, E<lt>yusrideb@cpan.orgE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2018 by Achmad Yusri Afandi
-
-=cut
